nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Dmactrl

Struct Dmactrl 

#[repr(transparent)]
pub struct Dmactrl(pub u32);
Selects DMA for Ports (if used)

Tuple Fields

0: u32

Implementations

Source

impl Dmactrl

pub const fn dma0en(&self) -> Dma0en

Enables the DMA use on the 1st channel for eSPI and selects what triggers it

pub const fn set_dma0en(&mut self, val: Dma0en)

Enables the DMA use on the 1st channel for eSPI and selects what triggers it

pub const fn dma1en(&self) -> Dma1en

Enables the DMA use on the 1st channel for eSPI and selects what triggers it

pub const fn set_dma1en(&mut self, val: Dma1en)

Enables the DMA use on the 1st channel for eSPI and selects what triggers it

pub const fn dma0port(&self) -> u8

Selects which port is operating the DMA: Value Meaning 0 to 7 Is normal port number up to max ports (e

pub const fn set_dma0port(&mut self, val: u8)

Selects which port is operating the DMA: Value Meaning 0 to 7 Is normal port number up to max ports (e

pub const fn dma1port(&self) -> u8

Selects which port is operating the DMA: Value Meaning 0 to 7 Is normal port number up to max ports (e

pub const fn set_dma1port(&mut self, val: u8)

Selects which port is operating the DMA: Value Meaning 0 to 7 Is normal port number up to max ports (e

pub const fn cnt0(&self) -> u8

Used with Mailbox and Bus master to allow RAM contents to be copied

pub const fn set_cnt0(&mut self, val: u8)

Used with Mailbox and Bus master to allow RAM contents to be copied

pub const fn cnt1(&self) -> u8

Used with Mailbox and Bus master to allow RAM contents to be copied

pub const fn set_cnt1(&mut self, val: u8)

Used with Mailbox and Bus master to allow RAM contents to be copied