nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Espicap

Struct Espicap 

#[repr(transparent)]
pub struct Espicap(pub u32);
eSPI Capabilities of MCU to send to Host

Tuple Fields

0: u32

Implementations

Source

impl Espicap

pub const fn spicap(&self) -> Spicap

SPI mode allowed (host still has to select):

pub const fn set_spicap(&mut self, val: Spicap)

SPI mode allowed (host still has to select):

pub const fn maxspd(&self) -> Maxspd

Maximum SPI Clock speed to allow (host still chooses):

pub const fn set_maxspd(&mut self, val: Maxspd)

Maximum SPI Clock speed to allow (host still chooses):

pub const fn alpin(&self) -> bool

Allow Alert to be a pin if the Host wants

pub const fn set_alpin(&mut self, val: bool)

Allow Alert to be a pin if the Host wants

pub const fn oobok(&self) -> bool

If 1, allow OOB

pub const fn set_oobok(&mut self, val: bool)

If 1, allow OOB

pub const fn memmx(&self) -> bool

If 1, allow 128 byte payload for memory and OOB access, else limit to 64

pub const fn set_memmx(&mut self, val: bool)

If 1, allow 128 byte payload for memory and OOB access, else limit to 64

pub const fn flashmx(&self) -> Flashmx

Selects max Flash payload size to allow:

pub const fn set_flashmx(&mut self, val: Flashmx)

Selects max Flash payload size to allow:

pub const fn saf(&self) -> bool

If 1, then Slave Attached Flash is possible with this firmware

pub const fn set_saf(&mut self, val: bool)

If 1, then Slave Attached Flash is possible with this firmware

pub const fn safera(&self) -> Safera

Min Erase sector size allowed if SAF used

pub const fn set_safera(&mut self, val: Safera)

Min Erase sector size allowed if SAF used