nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Espicfg

Struct Espicfg 

#[repr(transparent)]
pub struct Espicfg(pub u32);
eSPI Configuration settings from eSPI

Tuple Fields

0: u32

Implementations

Source

impl Espicfg

pub const fn memsz(&self) -> bool

If 1, will use 128 byte payload for memory and OOB access, else limited to 64

pub const fn set_memsz(&mut self, val: bool)

If 1, will use 128 byte payload for memory and OOB access, else limited to 64

pub const fn flashsz(&self) -> u8

Indicates max Flash payload size selected using same values as FLASHMX

pub const fn set_flashsz(&mut self, val: u8)

Indicates max Flash payload size selected using same values as FLASHMX

pub const fn spimod(&self) -> Spimod

SPI Mode selected by Host

pub const fn set_spimod(&mut self, val: Spimod)

SPI Mode selected by Host

pub const fn alert(&self) -> bool

Alert is a pin vs. MISO

pub const fn set_alert(&mut self, val: bool)

Alert is a pin vs. MISO

pub const fn alertod(&self) -> bool

Alert is OD as a pin

pub const fn set_alertod(&mut self, val: bool)

Alert is OD as a pin

pub const fn spispd(&self) -> Spispd

SPI Speed selected by Host. See note in section 2.2 on higher eSPI clock speeds and system setup.

pub const fn set_spispd(&mut self, val: Spispd)

SPI Speed selected by Host. See note in section 2.2 on higher eSPI clock speeds and system setup.

pub const fn crc(&self) -> bool

CRC checking is enabled

pub const fn set_crc(&mut self, val: bool)

CRC checking is enabled

pub const fn busmok(&self) -> bool

Bus Master is OK

pub const fn set_busmok(&mut self, val: bool)

Bus Master is OK

pub const fn memena(&self) -> bool

Channel 0 (memory) is enabled

pub const fn set_memena(&mut self, val: bool)

Channel 0 (memory) is enabled

pub const fn vwok(&self) -> bool

Channel 1 (Vwire) is enabled

pub const fn set_vwok(&mut self, val: bool)

Channel 1 (Vwire) is enabled

pub const fn oobok(&self) -> bool

Channel 2 (OOB) is enabled

pub const fn set_oobok(&mut self, val: bool)

Channel 2 (OOB) is enabled

pub const fn flshera(&self) -> Flshera

Flash erase size (and if enabled):

pub const fn set_flshera(&mut self, val: Flshera)

Flash erase size (and if enabled):

pub const fn flshok(&self) -> bool

Channel 3 (Flash) is enabled.

pub const fn set_flshok(&mut self, val: bool)

Channel 3 (Flash) is enabled.

pub const fn saf(&self) -> bool

Is 1 if Slave Attached Flash is enabled. Only possible if SAF is set in ESPICAP.

pub const fn set_saf(&mut self, val: bool)

Is 1 if Slave Attached Flash is enabled. Only possible if SAF is set in ESPICAP.