nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Espimisc

Struct Espimisc 

#[repr(transparent)]
pub struct Espimisc(pub u32);
Miscellaneous uses, such as Alert pin as GPIO (when not used for Alert).

Tuple Fields

0: u32

Implementations

Source

impl Espimisc

pub const fn gpio_oe(&self) -> bool

Set to 1 to make the Alert/Reset pin an output GPIO, else is input (High-Z)

pub const fn set_gpio_oe(&mut self, val: bool)

Set to 1 to make the Alert/Reset pin an output GPIO, else is input (High-Z)

pub const fn gpio_od(&self) -> bool

Set to 1 to make the Alert/Reset pin act open-drain when GPIO_OE=1

pub const fn set_gpio_od(&mut self, val: bool)

Set to 1 to make the Alert/Reset pin act open-drain when GPIO_OE=1

pub const fn gpio_out(&self) -> bool

Used when GPIO_OE=1

pub const fn set_gpio_out(&mut self, val: bool)

Used when GPIO_OE=1

pub const fn gpio_in(&self) -> bool

Is the current state of the Alert/Reset pin, whether in input mode or not

pub const fn set_gpio_in(&mut self, val: bool)

Is the current state of the Alert/Reset pin, whether in input mode or not

pub const fn risgp(&self) -> bool

Reset# is a GPIO

pub const fn set_risgp(&mut self, val: bool)

Reset# is a GPIO

pub const fn pwrsav(&self) -> bool

This bit, when set, will employ clock gating for the eSPI side

pub const fn set_pwrsav(&mut self, val: bool)

This bit, when set, will employ clock gating for the eSPI side