nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Intstat

Struct Intstat 

#[repr(transparent)]
pub struct Intstat(pub u32);
Masked interrupt status (causes)

Tuple Fields

0: u32

Implementations

Source

impl Intstat

pub const fn port_int(&self) -> u8

If set to 1, corresponding port will interrupt main processor if matches IRule

pub const fn set_port_int(&mut self, val: u8)

If set to 1, corresponding port will interrupt main processor if matches IRule

pub const fn p80int(&self) -> bool

If set to 1, Port80 will interrupt main processor on update from Host.

pub const fn set_p80int(&mut self, val: bool)

If set to 1, Port80 will interrupt main processor on update from Host.

pub const fn bus_rst(&self) -> bool

If 1, a change in Bus Reset status will interrupt main processor.

pub const fn set_bus_rst(&mut self, val: bool)

If 1, a change in Bus Reset status will interrupt main processor.

pub const fn irq_upd(&self) -> bool

If 1, completion of an IRQ update will interrupt main processor.

pub const fn set_irq_upd(&mut self, val: bool)

If 1, completion of an IRQ update will interrupt main processor.

pub const fn wire_chg(&self) -> bool

If 1, when one or more VWire input has changed, will interrupt main processor.

pub const fn set_wire_chg(&mut self, val: bool)

If 1, when one or more VWire input has changed, will interrupt main processor.

pub const fn hstall(&self) -> bool

If 1, when the HStall bit is set in the MSTAT register, will interrupt the main processor.

pub const fn set_hstall(&mut self, val: bool)

If 1, when the HStall bit is set in the MSTAT register, will interrupt the main processor.

pub const fn crcerr(&self) -> bool

If 1, when a CRC error detected, will interrupt main processor.

pub const fn set_crcerr(&mut self, val: bool)

If 1, when a CRC error detected, will interrupt main processor.

pub const fn gpio(&self) -> bool

If 1, when ESPICFG GPIO changes input value, will interrupt main processor.

pub const fn set_gpio(&mut self, val: bool)

If 1, when ESPICFG GPIO changes input value, will interrupt main processor.