nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Mctrl

Struct Mctrl 

#[repr(transparent)]
pub struct Mctrl(pub u32);
Master Control for whole peripheral

Tuple Fields

0: u32

Implementations

Source

impl Mctrl

pub const fn enable(&self) -> Enable

The main enable for the whole block

pub const fn set_enable(&mut self, val: Enable)

The main enable for the whole block

pub const fn pena(&self) -> u8

Port enable bits.

pub const fn set_pena(&mut self, val: u8)

Port enable bits.

pub const fn p80ena(&self) -> bool

Port 80 enable.

pub const fn set_p80ena(&mut self, val: bool)

Port 80 enable.

pub const fn sblkena(&self) -> bool

Status block is enabled and mapped according to the STATADDR register.

pub const fn set_sblkena(&mut self, val: bool)

Status block is enabled and mapped according to the STATADDR register.

pub const fn use60mhz(&self) -> bool

If 1, then the functional clock provided to the block is 60MHz vs

pub const fn set_use60mhz(&mut self, val: bool)

If 1, then the functional clock provided to the block is 60MHz vs