nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Mstat

Struct Mstat 

#[repr(transparent)]
pub struct Mstat(pub u32);
Master Status of whole peripheral

Tuple Fields

0: u32

Implementations

Source

impl Mstat

pub const fn port_int(&self) -> u8

Corresponding port is pending interrupt service

pub const fn set_port_int(&mut self, val: u8)

Corresponding port is pending interrupt service

pub const fn p80int(&self) -> bool

Port80 has had a request and is pending service.

pub const fn set_p80int(&mut self, val: bool)

Port80 has had a request and is pending service.

pub const fn bus_rst(&self) -> bool

If 1, the entered or left reset. Sticky - must clear.

pub const fn set_bus_rst(&mut self, val: bool)

If 1, the entered or left reset. Sticky - must clear.

pub const fn irq_upd(&self) -> bool

If 1, the bus had an IRQ update completion (for eSPI, IRQPush done; for LPC, SERIRQ done)

pub const fn set_irq_upd(&mut self, val: bool)

If 1, the bus had an IRQ update completion (for eSPI, IRQPush done; for LPC, SERIRQ done)

pub const fn wire_chg(&self) -> bool

If 1, one or more input VWire has changed since last cleared for eSPI; for LPC, SERIRQ started

pub const fn set_wire_chg(&mut self, val: bool)

If 1, one or more input VWire has changed since last cleared for eSPI; for LPC, SERIRQ started

pub const fn hstall(&self) -> bool

If 1, the Host is stalled on a read from or write to a port that has the StallRd or StallWr bit set in the PnCFG register

pub const fn set_hstall(&mut self, val: bool)

If 1, the Host is stalled on a read from or write to a port that has the StallRd or StallWr bit set in the PnCFG register

pub const fn crcerr(&self) -> bool

If 1, the CRC from the Master did not match the computed CRC

pub const fn set_crcerr(&mut self, val: bool)

If 1, the CRC from the Master did not match the computed CRC

pub const fn gpio(&self) -> bool

If 1, the GPIO in ESPIMISC has had an input change

pub const fn set_gpio(&mut self, val: bool)

If 1, the GPIO in ESPIMISC has had an input change

pub const fn busy(&self) -> bool

If 1, the bus is busy.

pub const fn set_busy(&mut self, val: bool)

If 1, the bus is busy.

pub const fn in_rst(&self) -> bool

If 1, the bus in reset.

pub const fn set_in_rst(&mut self, val: bool)

If 1, the bus in reset.

pub const fn comp_pend(&self) -> bool

If 1, completions are pending for eSPI; indicates quiet mode for LPC.

pub const fn set_comp_pend(&mut self, val: bool)

If 1, completions are pending for eSPI; indicates quiet mode for LPC.

pub const fn mast_pend(&self) -> bool

If 1, Mastering is pending (flash or memory)

pub const fn set_mast_pend(&mut self, val: bool)

If 1, Mastering is pending (flash or memory)

pub const fn alert_pend(&self) -> bool

If 1, the Alert request pin is pending (whether separate pin or MISO)

pub const fn set_alert_pend(&mut self, val: bool)

If 1, the Alert request pin is pending (whether separate pin or MISO)