#[repr(transparent)]pub struct P0iruleStat(pub u32);Expand description
The Port Set Interrupt-Rule and Set User Status register is used to set: The interrupt causes per port. That is, it is used to select what events from the port should cause an interrupt, if any. The user Status bits. The status byte returned to the host will be composed of both these user bits (which the application defines) and automatically generated status. The interrupt masks then are matched by sticky cause bits in PnSTAT (which can be read and then write-1 cleared). The sticky bits are set whether the interrupt is masked or not, but the masks cause an interrupt when the bits are set and the port is int enabled via INTENSET.
Tuple Fields
0: u32Implementations
Sourceimpl P0iruleStat
impl P0iruleStat
Sourcepub const fn ustat(&self) -> u8
pub const fn ustat(&self) -> u8
User defined status bits. These are salted into the status register as specified in section 4.1 and 4.6.
Sourcepub const fn set_ustat(&mut self, val: u8)
pub const fn set_ustat(&mut self, val: u8)
User defined status bits. These are salted into the status register as specified in section 4.1 and 4.6.
Sourcepub const fn interr(&self) -> bool
pub const fn interr(&self) -> bool
Interrupt if an error is detected (classes of error defined in section 2.14)
Sourcepub const fn set_interr(&mut self, val: bool)
pub const fn set_interr(&mut self, val: bool)
Interrupt if an error is detected (classes of error defined in section 2.14)
Sourcepub const fn set_intrd(&mut self, val: bool)
pub const fn set_intrd(&mut self, val: bool)
Interrupt if Read or 1st Read or Bus master Started.
Sourcepub const fn set_intwr(&mut self, val: bool)
pub const fn set_intwr(&mut self, val: bool)
Interrupt if Write or 1st Write or Bus master Finished.
Sourcepub const fn intspc(&self) -> u8
pub const fn intspc(&self) -> u8
Interrupt if: Bit Endpoint Idx/Data Mbox BusMaster/Flash SPC0 CMD Idx Change Write 0 Completed SPC1 - - Read 0 - SPC2 - - Write Last - SPC3 - - Read Last -
Sourcepub const fn set_intspc(&mut self, val: u8)
pub const fn set_intspc(&mut self, val: u8)
Interrupt if: Bit Endpoint Idx/Data Mbox BusMaster/Flash SPC0 CMD Idx Change Write 0 Completed SPC1 - - Read 0 - SPC2 - - Write Last - SPC3 - - Read Last -