nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

P0stat

Struct P0stat 

#[repr(transparent)]
pub struct P0stat(pub u32);
no description available

Tuple Fields

0: u32

Implementations

Source

impl P0stat

pub const fn rdstat(&self) -> u8

Status of Host Read data

pub const fn set_rdstat(&mut self, val: u8)

Status of Host Read data

pub const fn wrstat(&self) -> u8

Status of Host Writes

pub const fn set_wrstat(&mut self, val: u8)

Status of Host Writes

pub const fn interr(&self) -> bool

Interrupt was caused by error

pub const fn set_interr(&mut self, val: bool)

Interrupt was caused by error

pub const fn intrd(&self) -> bool

Interrupt was caused by Read or 1st Read or Bus master Started.

pub const fn set_intrd(&mut self, val: bool)

Interrupt was caused by Read or 1st Read or Bus master Started.

pub const fn intwr(&self) -> bool

Interrupt was caused by Write or 1st Write or Bus master Started.

pub const fn set_intwr(&mut self, val: bool)

Interrupt was caused by Write or 1st Write or Bus master Started.

pub const fn intspc(&self) -> u8

Interrupt was caused by: Bit Endpoint Idx/Data Mbox BusMaster/Flash SPC0 CMD Idx Change Write 0 Completed SPC1 - - Read 0 - SPC2 - - Write Last - SPC3 - - Read Last -

pub const fn set_intspc(&mut self, val: u8)

Interrupt was caused by: Bit Endpoint Idx/Data Mbox BusMaster/Flash SPC0 CMD Idx Change Write 0 Completed SPC1 - - Read 0 - SPC2 - - Write Last - SPC3 - - Read Last -

pub const fn err(&self) -> u8

Cause of INTERR: Bit Endpoint, Idx/Data Mbox BusMaster/Flash ERR0 Host Write Over Host Write or Read invalid for Access Failed From-Host (cannot tell on Memory To-Host, but can for Flash write)

pub const fn set_err(&mut self, val: u8)

Cause of INTERR: Bit Endpoint, Idx/Data Mbox BusMaster/Flash ERR0 Host Write Over Host Write or Read invalid for Access Failed From-Host (cannot tell on Memory To-Host, but can for Flash write)