nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

P1cfg

Struct P1cfg 

#[repr(transparent)]
pub struct P1cfg(pub u32);
no description available

Tuple Fields

0: u32

Implementations

Source

impl P1cfg

pub const fn type_(&self) -> P1cfgType

The Type field selects how the port interacts with the Host over the eSPI or LPC bus

pub const fn set_type_(&mut self, val: P1cfgType)

The Type field selects how the port interacts with the Host over the eSPI or LPC bus

pub const fn direction(&self) -> u8

Meaning depends on Type, but generally picks the direction of the port (Host writes, Host reads, or both)

pub const fn set_direction(&mut self, val: u8)

Meaning depends on Type, but generally picks the direction of the port (Host writes, Host reads, or both)

pub const fn mbint_all(&self) -> bool

Mailbox: Map interrupt on Read 1st and Write 1st to every read/write (special will still control 0th and last location)

pub const fn set_mbint_all(&mut self, val: bool)

Mailbox: Map interrupt on Read 1st and Write 1st to every read/write (special will still control 0th and last location)

pub const fn stall_rd(&self) -> bool

Stall on any Read of Index/Data and Mailbox (only)

pub const fn set_stall_rd(&mut self, val: bool)

Stall on any Read of Index/Data and Mailbox (only)

pub const fn stall_wr(&self) -> bool

Stall on any Write of Index/Data and Mailbox

pub const fn set_stall_wr(&mut self, val: bool)

Stall on any Write of Index/Data and Mailbox

pub const fn error_ign(&self) -> bool

If 1, the Host will get an error when trying to perform a read or write that is blocked by the Direction field

pub const fn set_error_ign(&mut self, val: bool)

If 1, the Host will get an error when trying to perform a read or write that is blocked by the Direction field