nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

P1iruleStat

Struct P1iruleStat 

#[repr(transparent)]
pub struct P1iruleStat(pub u32);
The Port Set Interrupt-Rule and Set User Status register is used to set: The interrupt causes per port. That is, it is used to select what events from the port should cause an interrupt, if any. The user Status bits. The status byte returned to the host will be composed of both these user bits (which the application defines) and automatically generated status. The interrupt masks then are matched by sticky cause bits in PnSTAT (which can be read and then write-1 cleared). The sticky bits are set whether the interrupt is masked or not, but the masks cause an interrupt when the bits are set and the port is int enabled via INTENSET.

Tuple Fields

0: u32

Implementations

Source

impl P1iruleStat

pub const fn ustat(&self) -> u8

User defined status bits. These are salted into the status register as specified in section 4.1 and 4.6.

pub const fn set_ustat(&mut self, val: u8)

User defined status bits. These are salted into the status register as specified in section 4.1 and 4.6.

pub const fn interr(&self) -> bool

Interrupt if an error is detected (classes of error defined in section 2.14)

pub const fn set_interr(&mut self, val: bool)

Interrupt if an error is detected (classes of error defined in section 2.14)

pub const fn intrd(&self) -> bool

Interrupt if Read or 1st Read or Bus master Started.

pub const fn set_intrd(&mut self, val: bool)

Interrupt if Read or 1st Read or Bus master Started.

pub const fn intwr(&self) -> bool

Interrupt if Write or 1st Write or Bus master Finished.

pub const fn set_intwr(&mut self, val: bool)

Interrupt if Write or 1st Write or Bus master Finished.

pub const fn intspc(&self) -> u8

Interrupt if: Bit Endpoint Idx/Data Mbox BusMaster/Flash SPC0 CMD Idx Change Write 0 Completed SPC1 - - Read 0 - SPC2 - - Write Last - SPC3 - - Read Last -

pub const fn set_intspc(&mut self, val: u8)

Interrupt if: Bit Endpoint Idx/Data Mbox BusMaster/Flash SPC0 CMD Idx Change Write 0 Completed SPC1 - - Read 0 - SPC2 - - Write Last - SPC3 - - Read Last -

pub const fn sstcl(&self) -> u8

Status set/clear

pub const fn set_sstcl(&mut self, val: u8)

Status set/clear

pub const fn srst(&self) -> bool

Resets the RdStatus and WrStatus in PStatus register

pub const fn set_srst(&mut self, val: bool)

Resets the RdStatus and WrStatus in PStatus register