nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

P2ramuse

Struct P2ramuse 

#[repr(transparent)]
pub struct P2ramuse(pub u32);
no description available

Tuple Fields

0: u32

Implementations

Source

impl P2ramuse

pub const fn off(&self) -> u16

This is the word offset into the RAM

pub const fn set_off(&mut self, val: u16)

This is the word offset into the RAM

pub const fn len(&self) -> u8

This is the length of the mailbox or mastering area as 4<<LEN per direction

pub const fn set_len(&mut self, val: u8)

This is the length of the mailbox or mastering area as 4<<LEN per direction