#[repr(transparent)]pub struct P3dataIn(pub u32);Expand description
no description available
Tuple Fields
0: u32Implementations
Sourceimpl P3dataIn
impl P3dataIn
Sourcepub const fn data_len(&self) -> u8
pub const fn data_len(&self) -> u8
Meaning is dependent on type of port: If endpoint or index/data: is data byte If Mailbox or Bus master or Flash: is count in last message, 0 relative If SAF, is count in last message including address (so, +4), 0 relative
Sourcepub const fn set_data_len(&mut self, val: u8)
pub const fn set_data_len(&mut self, val: u8)
Meaning is dependent on type of port: If endpoint or index/data: is data byte If Mailbox or Bus master or Flash: is count in last message, 0 relative If SAF, is count in last message including address (so, +4), 0 relative