nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

P4dataIn

Struct P4dataIn 

#[repr(transparent)]
pub struct P4dataIn(pub u32);
no description available

Tuple Fields

0: u32

Implementations

Source

impl P4dataIn

pub const fn data_len(&self) -> u8

Meaning is dependent on type of port: If endpoint or index/data: is data byte If Mailbox or Bus master or Flash: is count in last message, 0 relative If SAF, is count in last message including address (so, +4), 0 relative

pub const fn set_data_len(&mut self, val: u8)

Meaning is dependent on type of port: If endpoint or index/data: is data byte If Mailbox or Bus master or Flash: is count in last message, 0 relative If SAF, is count in last message including address (so, +4), 0 relative

pub const fn dir(&self) -> bool

Direction of last access: 0 = Read By Host 1 = Write By Host

pub const fn set_dir(&mut self, val: bool)

Direction of last access: 0 = Read By Host 1 = Write By Host

pub const fn idx(&self) -> u16

Index of last access (ie

pub const fn set_idx(&mut self, val: u16)

Index of last access (ie