nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Rambase

Struct Rambase 

#[repr(transparent)]
pub struct Rambase(pub u32);
Address of RAM to use for data. This tells the application where the RAM is located (up to 16K addressable).

Tuple Fields

0: u32

Implementations

Source

impl Rambase

pub const fn zero(&self) -> u16

Always 0

pub const fn set_zero(&mut self, val: u16)

Always 0

pub const fn ram(&self) -> u32

Is location in System memory space where RAM is located that is used by this peripheral’s bus master

pub const fn set_ram(&mut self, val: u32)

Is location in System memory space where RAM is located that is used by this peripheral’s bus master