nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Stataddr

Struct Stataddr 

#[repr(transparent)]
pub struct Stataddr(pub u32);
Location of Status block in memory space, if enabled.

Tuple Fields

0: u32

Implementations

Source

impl Stataddr

pub const fn off(&self) -> u16

The offset in Host space for the status block. It must be double-word aligned.

pub const fn set_off(&mut self, val: u16)

The offset in Host space for the status block. It must be double-word aligned.

pub const fn base(&self) -> Base

The meaning is dependent on type of port:

pub const fn set_base(&mut self, val: Base)

The meaning is dependent on type of port: