nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Wirero

Struct Wirero 

#[repr(transparent)]
pub struct Wirero(pub u32);
Wire states from Host

Tuple Fields

0: u32

Implementations

Source

impl Wirero

pub const fn wires(&self) -> u32

eSPI: Indicates the latest states from the Host via VWire

pub const fn set_wires(&mut self, val: u32)

eSPI: Indicates the latest states from the Host via VWire