nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Wirewo

Struct Wirewo 

#[repr(transparent)]
pub struct Wirewo(pub u32);
Wire states for Host to see; if LPC, this is the IRQ states.

Tuple Fields

0: u32

Implementations

Source

impl Wirewo

pub const fn wires(&self) -> u32

LPC: IRQ states to use

pub const fn set_wires(&mut self, val: u32)

LPC: IRQ states to use

pub const fn done(&self) -> bool

Set to 1 after last write has been pushed out to Host

pub const fn set_done(&mut self, val: bool)

Set to 1 after last write has been pushed out to Host