#[repr(transparent)]pub struct Dmactrl(pub u32);Expand description
Selects DMA for Ports (if used)
Tuple Fields
0: u32Implementations
Sourceimpl Dmactrl
impl Dmactrl
Sourcepub const fn dma0en(&self) -> Dma0en
pub const fn dma0en(&self) -> Dma0en
Enables the DMA use on the 1st channel for eSPI and selects what triggers it
Sourcepub const fn set_dma0en(&mut self, val: Dma0en)
pub const fn set_dma0en(&mut self, val: Dma0en)
Enables the DMA use on the 1st channel for eSPI and selects what triggers it
Sourcepub const fn dma1en(&self) -> Dma1en
pub const fn dma1en(&self) -> Dma1en
Enables the DMA use on the 1st channel for eSPI and selects what triggers it
Sourcepub const fn set_dma1en(&mut self, val: Dma1en)
pub const fn set_dma1en(&mut self, val: Dma1en)
Enables the DMA use on the 1st channel for eSPI and selects what triggers it
Sourcepub const fn dma0port(&self) -> u8
pub const fn dma0port(&self) -> u8
Selects which port is operating the DMA: Value Meaning 0 to 7 Is normal port number up to max ports (e
Sourcepub const fn set_dma0port(&mut self, val: u8)
pub const fn set_dma0port(&mut self, val: u8)
Selects which port is operating the DMA: Value Meaning 0 to 7 Is normal port number up to max ports (e
Sourcepub const fn dma1port(&self) -> u8
pub const fn dma1port(&self) -> u8
Selects which port is operating the DMA: Value Meaning 0 to 7 Is normal port number up to max ports (e
Sourcepub const fn set_dma1port(&mut self, val: u8)
pub const fn set_dma1port(&mut self, val: u8)
Selects which port is operating the DMA: Value Meaning 0 to 7 Is normal port number up to max ports (e
Sourcepub const fn cnt0(&self) -> u8
pub const fn cnt0(&self) -> u8
Used with Mailbox and Bus master to allow RAM contents to be copied
Sourcepub const fn set_cnt0(&mut self, val: u8)
pub const fn set_cnt0(&mut self, val: u8)
Used with Mailbox and Bus master to allow RAM contents to be copied