#[repr(transparent)]pub struct Espicfg(pub u32);Expand description
eSPI Configuration settings from eSPI
Tuple Fields
0: u32Implementations
Sourceimpl Espicfg
impl Espicfg
Sourcepub const fn memsz(&self) -> bool
pub const fn memsz(&self) -> bool
If 1, will use 128 byte payload for memory and OOB access, else limited to 64
Sourcepub const fn set_memsz(&mut self, val: bool)
pub const fn set_memsz(&mut self, val: bool)
If 1, will use 128 byte payload for memory and OOB access, else limited to 64
Sourcepub const fn flashsz(&self) -> u8
pub const fn flashsz(&self) -> u8
Indicates max Flash payload size selected using same values as FLASHMX
Sourcepub const fn set_flashsz(&mut self, val: u8)
pub const fn set_flashsz(&mut self, val: u8)
Indicates max Flash payload size selected using same values as FLASHMX
Sourcepub const fn set_spimod(&mut self, val: Spimod)
pub const fn set_spimod(&mut self, val: Spimod)
SPI Mode selected by Host
Sourcepub const fn set_alertod(&mut self, val: bool)
pub const fn set_alertod(&mut self, val: bool)
Alert is OD as a pin
Sourcepub const fn spispd(&self) -> Spispd
pub const fn spispd(&self) -> Spispd
SPI Speed selected by Host. See note in section 2.2 on higher eSPI clock speeds and system setup.
Sourcepub const fn set_spispd(&mut self, val: Spispd)
pub const fn set_spispd(&mut self, val: Spispd)
SPI Speed selected by Host. See note in section 2.2 on higher eSPI clock speeds and system setup.
Sourcepub const fn set_busmok(&mut self, val: bool)
pub const fn set_busmok(&mut self, val: bool)
Bus Master is OK
Sourcepub const fn set_memena(&mut self, val: bool)
pub const fn set_memena(&mut self, val: bool)
Channel 0 (memory) is enabled
Sourcepub const fn set_flshera(&mut self, val: Flshera)
pub const fn set_flshera(&mut self, val: Flshera)
Flash erase size (and if enabled):
Sourcepub const fn set_flshok(&mut self, val: bool)
pub const fn set_flshok(&mut self, val: bool)
Channel 3 (Flash) is enabled.