#[repr(transparent)]pub struct Espimisc(pub u32);Expand description
Miscellaneous uses, such as Alert pin as GPIO (when not used for Alert).
Tuple Fields
0: u32Implementations
Sourceimpl Espimisc
impl Espimisc
Sourcepub const fn gpio_oe(&self) -> bool
pub const fn gpio_oe(&self) -> bool
Set to 1 to make the Alert/Reset pin an output GPIO, else is input (High-Z)
Sourcepub const fn set_gpio_oe(&mut self, val: bool)
pub const fn set_gpio_oe(&mut self, val: bool)
Set to 1 to make the Alert/Reset pin an output GPIO, else is input (High-Z)
Sourcepub const fn gpio_od(&self) -> bool
pub const fn gpio_od(&self) -> bool
Set to 1 to make the Alert/Reset pin act open-drain when GPIO_OE=1
Sourcepub const fn set_gpio_od(&mut self, val: bool)
pub const fn set_gpio_od(&mut self, val: bool)
Set to 1 to make the Alert/Reset pin act open-drain when GPIO_OE=1
Sourcepub const fn set_gpio_out(&mut self, val: bool)
pub const fn set_gpio_out(&mut self, val: bool)
Used when GPIO_OE=1
Sourcepub const fn gpio_in(&self) -> bool
pub const fn gpio_in(&self) -> bool
Is the current state of the Alert/Reset pin, whether in input mode or not
Sourcepub const fn set_gpio_in(&mut self, val: bool)
pub const fn set_gpio_in(&mut self, val: bool)
Is the current state of the Alert/Reset pin, whether in input mode or not
Sourcepub const fn pwrsav(&self) -> bool
pub const fn pwrsav(&self) -> bool
This bit, when set, will employ clock gating for the eSPI side
Sourcepub const fn set_pwrsav(&mut self, val: bool)
pub const fn set_pwrsav(&mut self, val: bool)
This bit, when set, will employ clock gating for the eSPI side