#[repr(transparent)]pub struct Intstat(pub u32);Expand description
Masked interrupt status (causes)
Tuple Fields
0: u32Implementations
Sourceimpl Intstat
impl Intstat
Sourcepub const fn port_int(&self) -> u8
pub const fn port_int(&self) -> u8
If set to 1, corresponding port will interrupt main processor if matches IRule
Sourcepub const fn set_port_int(&mut self, val: u8)
pub const fn set_port_int(&mut self, val: u8)
If set to 1, corresponding port will interrupt main processor if matches IRule
Sourcepub const fn p80int(&self) -> bool
pub const fn p80int(&self) -> bool
If set to 1, Port80 will interrupt main processor on update from Host.
Sourcepub const fn set_p80int(&mut self, val: bool)
pub const fn set_p80int(&mut self, val: bool)
If set to 1, Port80 will interrupt main processor on update from Host.
Sourcepub const fn bus_rst(&self) -> bool
pub const fn bus_rst(&self) -> bool
If 1, a change in Bus Reset status will interrupt main processor.
Sourcepub const fn set_bus_rst(&mut self, val: bool)
pub const fn set_bus_rst(&mut self, val: bool)
If 1, a change in Bus Reset status will interrupt main processor.
Sourcepub const fn irq_upd(&self) -> bool
pub const fn irq_upd(&self) -> bool
If 1, completion of an IRQ update will interrupt main processor.
Sourcepub const fn set_irq_upd(&mut self, val: bool)
pub const fn set_irq_upd(&mut self, val: bool)
If 1, completion of an IRQ update will interrupt main processor.
Sourcepub const fn wire_chg(&self) -> bool
pub const fn wire_chg(&self) -> bool
If 1, when one or more VWire input has changed, will interrupt main processor.
Sourcepub const fn set_wire_chg(&mut self, val: bool)
pub const fn set_wire_chg(&mut self, val: bool)
If 1, when one or more VWire input has changed, will interrupt main processor.
Sourcepub const fn hstall(&self) -> bool
pub const fn hstall(&self) -> bool
If 1, when the HStall bit is set in the MSTAT register, will interrupt the main processor.
Sourcepub const fn set_hstall(&mut self, val: bool)
pub const fn set_hstall(&mut self, val: bool)
If 1, when the HStall bit is set in the MSTAT register, will interrupt the main processor.
Sourcepub const fn crcerr(&self) -> bool
pub const fn crcerr(&self) -> bool
If 1, when a CRC error detected, will interrupt main processor.
Sourcepub const fn set_crcerr(&mut self, val: bool)
pub const fn set_crcerr(&mut self, val: bool)
If 1, when a CRC error detected, will interrupt main processor.