#[repr(transparent)]pub struct Mctrl(pub u32);Expand description
Master Control for whole peripheral
Tuple Fields
0: u32Implementations
Sourceimpl Mctrl
impl Mctrl
Sourcepub const fn set_enable(&mut self, val: Enable)
pub const fn set_enable(&mut self, val: Enable)
The main enable for the whole block
Sourcepub const fn set_p80ena(&mut self, val: bool)
pub const fn set_p80ena(&mut self, val: bool)
Port 80 enable.
Sourcepub const fn sblkena(&self) -> bool
pub const fn sblkena(&self) -> bool
Status block is enabled and mapped according to the STATADDR register.
Sourcepub const fn set_sblkena(&mut self, val: bool)
pub const fn set_sblkena(&mut self, val: bool)
Status block is enabled and mapped according to the STATADDR register.
Sourcepub const fn use60mhz(&self) -> bool
pub const fn use60mhz(&self) -> bool
If 1, then the functional clock provided to the block is 60MHz vs
Sourcepub const fn set_use60mhz(&mut self, val: bool)
pub const fn set_use60mhz(&mut self, val: bool)
If 1, then the functional clock provided to the block is 60MHz vs