#[repr(transparent)]pub struct P1cfg(pub u32);Expand description
no description available
Tuple Fields
0: u32Implementations
Sourceimpl P1cfg
impl P1cfg
Sourcepub const fn type_(&self) -> P1cfgType
pub const fn type_(&self) -> P1cfgType
The Type field selects how the port interacts with the Host over the eSPI or LPC bus
Sourcepub const fn set_type_(&mut self, val: P1cfgType)
pub const fn set_type_(&mut self, val: P1cfgType)
The Type field selects how the port interacts with the Host over the eSPI or LPC bus
Sourcepub const fn direction(&self) -> u8
pub const fn direction(&self) -> u8
Meaning depends on Type, but generally picks the direction of the port (Host writes, Host reads, or both)
Sourcepub const fn set_direction(&mut self, val: u8)
pub const fn set_direction(&mut self, val: u8)
Meaning depends on Type, but generally picks the direction of the port (Host writes, Host reads, or both)
Sourcepub const fn mbint_all(&self) -> bool
pub const fn mbint_all(&self) -> bool
Mailbox: Map interrupt on Read 1st and Write 1st to every read/write (special will still control 0th and last location)
Sourcepub const fn set_mbint_all(&mut self, val: bool)
pub const fn set_mbint_all(&mut self, val: bool)
Mailbox: Map interrupt on Read 1st and Write 1st to every read/write (special will still control 0th and last location)
Sourcepub const fn set_stall_rd(&mut self, val: bool)
pub const fn set_stall_rd(&mut self, val: bool)
Stall on any Read of Index/Data and Mailbox (only)
Sourcepub const fn set_stall_wr(&mut self, val: bool)
pub const fn set_stall_wr(&mut self, val: bool)
Stall on any Write of Index/Data and Mailbox
Sourcepub const fn error_ign(&self) -> bool
pub const fn error_ign(&self) -> bool
If 1, the Host will get an error when trying to perform a read or write that is blocked by the Direction field
Sourcepub const fn set_error_ign(&mut self, val: bool)
pub const fn set_error_ign(&mut self, val: bool)
If 1, the Host will get an error when trying to perform a read or write that is blocked by the Direction field